@@ -18,7 +18,7 @@ our @EXPORT_OK = qw( cldr_format cldr_parse );
 
 # CPAN data
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = "1.15";
+our $VERSION = '1.16';
 
 # Default format if none is set
 our $DEFAULT_FORMAT = 'date_format_medium';
@@ -644,8 +644,7 @@ sub parse_datetime {
             } elsif ($command eq 'H') { # 0-23
                 $datetime{hour} = $capture;
             } elsif ($command eq 'k') { # 1-24
-                $capture = 0 if $capture == 24;
-                $datetime{hour} = $capture;
+                $datetime_info{hour24} = $capture;
             } elsif ($command eq 'm') {
                 $datetime{minute} = $capture;
             } elsif ($command eq 's') {
@@ -687,6 +686,12 @@ sub parse_datetime {
         $datetime{hour} += 12
             if $datetime_info{ampm} == 2 && $datetime{hour} < 12;
     }
+    if (defined $datetime_info{hour24}) {
+        $datetime{hour} = $datetime_info{hour24};
+        if ($datetime{hour} == 24) {
+            $datetime{hour} = 0;
+        }
+    }
     
     # Handle 24:00:00 time notations
     if ($datetime{hour} == 24) {
@@ -1003,7 +1008,7 @@ be parsed but ignored in datetime calculation.
 
 See L<DateTime/"CLDR Patterns">.
 
-CLDR provides the following pattenrs:
+CLDR provides the following patterns:
 
 =over 4
 
@@ -1227,7 +1232,8 @@ The hour from 0-11.
 
 =item * k{1,2}
 
-The hour from 1-24.
+The hour from 1-24. Note that hour 24 is equivalent to midnight on the date
+being parsed, not midnight of the next day.
 
 =item * j{1,2}
 
